pypaginate.text
===============

.. py:module:: pypaginate.text

.. autoapi-nested-parse::

   Text normalization using Python stdlib unicodedata.



Submodules
----------

.. toctree::
   :maxdepth: 1

   /api/pypaginate/text/normalize/index


